@@ -5,7 +5,7 @@ use crate::common;
 use rand::seq::SliceRandom;
 
 /// Load the front page in English and all static assets found on the page.
-pub async fn front_page_en(user: &GooseUser) -> GooseTaskResult {
+pub async fn front_page_en(user: &mut GooseUser) -> GooseTaskResult {
     let goose = user.get("/").await?;
     common::validate_and_load_static_assets(user, goose, "Home").await?;
 
@@ -13,7 +13,7 @@ pub async fn front_page_en(user: &GooseUser) -> GooseTaskResult {
 }
 
 /// Load recipe listing in English and all static assets found on the page.
-pub async fn recipe_listing_en(user: &GooseUser) -> GooseTaskResult {
+pub async fn recipe_listing_en(user: &mut GooseUser) -> GooseTaskResult {
     let goose = user.get("/en/recipes/").await?;
     common::validate_and_load_static_assets(user, goose, "Recipes").await?;
 
@@ -21,7 +21,7 @@ pub async fn recipe_listing_en(user: &GooseUser) -> GooseTaskResult {
 }
 
 /// Load a random recipe in English and all static assets found on the page.
-pub async fn recipe_en(user: &GooseUser) -> GooseTaskResult {
+pub async fn recipe_en(user: &mut GooseUser) -> GooseTaskResult {
     let nodes = common::get_nodes(&common::ContentType::Recipe);
     let recipe = nodes.choose(&mut rand::thread_rng());
     let goose = user.get(recipe.unwrap().url_en).await?;
@@ -31,7 +31,7 @@ pub async fn recipe_en(user: &GooseUser) -> GooseTaskResult {
 }
 
 /// Load article listing in English and all static assets found on the page.
-pub async fn article_listing_en(user: &GooseUser) -> GooseTaskResult {
+pub async fn article_listing_en(user: &mut GooseUser) -> GooseTaskResult {
     let goose = user.get("/en/articles/").await?;
     common::validate_and_load_static_assets(user, goose, "Articles").await?;
 
@@ -39,7 +39,7 @@ pub async fn article_listing_en(user: &GooseUser) -> GooseTaskResult {
 }
 
 /// Load a random article in English and all static assets found on the page.
-pub async fn article_en(user: &GooseUser) -> GooseTaskResult {
+pub async fn article_en(user: &mut GooseUser) -> GooseTaskResult {
     let nodes = common::get_nodes(&common::ContentType::Article);
     let article = nodes.choose(&mut rand::thread_rng());
     let goose = user.get(article.unwrap().url_en).await?;
@@ -49,7 +49,7 @@ pub async fn article_en(user: &GooseUser) -> GooseTaskResult {
 }
 
 /// Load a random basic page in English and all static assets found on the page.
-pub async fn basic_page_en(user: &GooseUser) -> GooseTaskResult {
+pub async fn basic_page_en(user: &mut GooseUser) -> GooseTaskResult {
     let nodes = common::get_nodes(&common::ContentType::BasicPage);
     let page = nodes.choose(&mut rand::thread_rng());
     let goose = user.get(page.unwrap().url_en).await?;
@@ -59,7 +59,7 @@ pub async fn basic_page_en(user: &GooseUser) -> GooseTaskResult {
 }
 
 /// Load a random node by nid in English and all static assets found on the page.
-pub async fn page_by_nid(user: &GooseUser) -> GooseTaskResult {
+pub async fn page_by_nid(user: &mut GooseUser) -> GooseTaskResult {
     // Randomly select a content type.
     let content_types = vec![
         common::ContentType::Article,
@@ -80,21 +80,21 @@ pub async fn page_by_nid(user: &GooseUser) -> GooseTaskResult {
 }
 
 /// Anonymously load the contact form in English and POST feedback.
-pub async fn anonymous_contact_form_en(user: &GooseUser) -> GooseTaskResult {
+pub async fn anonymous_contact_form_en(user: &mut GooseUser) -> GooseTaskResult {
     common::anonymous_contact_form(user, true).await?;
 
     Ok(())
 }
 
 // Pick a random word from the title of a random node and perform a search in English.
-pub async fn search_en(user: &GooseUser) -> GooseTaskResult {
+pub async fn search_en(user: &mut GooseUser) -> GooseTaskResult {
     common::search(user, true).await?;
 
     Ok(())
 }
 
 /// Load category listing by a random term in English and all static assets found on the page.
-pub async fn term_listing_en(user: &GooseUser) -> GooseTaskResult {
+pub async fn term_listing_en(user: &mut GooseUser) -> GooseTaskResult {
     let terms = common::get_terms();
     let term = terms.choose(&mut rand::thread_rng());
     let goose = user.get(term.unwrap().url_en).await?;
