@@ -5,7 +5,7 @@ use std::collections::HashSet;
 use std::io::BufWriter;
 use std::sync::atomic::{AtomicBool, AtomicUsize, Ordering};
 use std::sync::Arc;
-use std::{thread, time};
+use std::time;
 
 use crate::metrics::{
     self, GooseErrorMetricAggregate, GooseErrorMetrics, GooseRequestMetricAggregate,
@@ -25,10 +25,6 @@ pub struct GooseUserInitializer {
     pub task_sets_index: usize,
     /// The base_url for this user thread.
     pub base_url: String,
-    /// Minimum amount of time to sleep after running a task.
-    pub min_wait: usize,
-    /// Maximum amount of time to sleep after running a task.
-    pub max_wait: usize,
     /// A local copy of the global GooseConfiguration.
     pub config: GooseConfiguration,
     /// How long the load test should run, in seconds.
@@ -474,8 +470,6 @@ pub(crate) async fn manager_main(mut goose_attack: GooseAttack) -> GooseAttack {
                             users.push(GooseUserInitializer {
                                 task_sets_index: user.task_sets_index,
                                 base_url: user.base_url.read().await.to_string(),
-                                min_wait: user.min_wait,
-                                max_wait: user.max_wait,
                                 config: user.config.clone(),
                                 run_time: goose_attack.run_time,
                                 worker_id: workers.len(),
@@ -583,7 +577,7 @@ pub(crate) async fn manager_main(mut goose_attack: GooseAttack) -> GooseAttack {
                     }
                     if !load_test_finished {
                         // Sleep a tenth of a second then return to the loop.
-                        thread::sleep(time::Duration::from_millis(100));
+                        tokio::time::sleep(time::Duration::from_millis(100)).await;
                     }
                 } else {
                     panic!("error receiving user message: {}", e);
